<?php
/**
 * The template for displaying the header.
 *
 * Contains the opening of the id=page which is closed 
 * in footer template, just before body itself closes.
 *
 * @package Mimbolove
 * @since Mimbolove 1.0.2
 */
?>

<!doctype html>
<html <?php language_attributes();?>>

<head>

<title><?php
	/*
	 * Print the <title> tag based on what is being viewed.
	 */
	global $page, $paged;

	wp_title( '|', true, 'right' );

	// Add the blog name.
	bloginfo( 'name' );

	// Add the blog description for the home/front page.
	$site_description = get_bloginfo( 'description', 'display' );
	if ( $site_description && ( is_home() || is_front_page() ) )
		echo " | $site_description";

	// Add a page number if necessary:
	if ( $paged >= 2 || $page >= 2 )
		echo ' | ' . sprintf( __( 'Page %s', 'mimbolove' ), max( $paged, $page ) );

	?>
</title>
	
	

<meta http-equiv="Content-Type" content="<?php bloginfo('html_type'); ?>; charset=<?php bloginfo('charset'); ?>" />

<link rel="profile" href="http://gmpg.org/xfn/11" />
<link rel="stylesheet" type="text/css" media="all" href="<?php echo get_stylesheet_uri(); ?>" />
<link rel="pingback" href="<?php bloginfo( 'pingback_url' ); ?>" />

<?php
	/* We add some JavaScript to pages with the comment form
	 * to support sites with threaded comments (when in use).
	 */
	if ( is_singular() && get_option( 'thread_comments' ) )
		wp_enqueue_script( 'comment-reply' );

	/* Always have wp_head() just before the closing </head>
	 * tag of your theme, or you will break many plugins, which
	 * generally use this hook to add elements to <head> such
	 * as styles, scripts, and meta tags.
	 */
	wp_head();
?>

</head>
<body <?php body_class(); ?>>
<div id="mimba">
<div id="header" class="group">
	<div id="header-search-form" class="group">
			<?php 
				get_search_form();
				# This one animates a bit, if javascript is enabled.
			?>
	</div> <!-- close of id=header-search-form -->
	
<?php if ( has_nav_menu( 'header-menu' ) ) {
		# An optional header navigation menu.
	?>	
		<div id="access" role="navigation">		
	<?php
		wp_nav_menu( array( 
				'theme_location' => 'header-menu',
				'before'          => '',
				'after'           => '',
				'container_class' => '',
				'container'       => '',
				'menu_id'         => '',
				'items_wrap'      => '<ul>%3$s</ul>',
			)
		);
	?>
		</div> <!-- close of id="access" -->
	<?php } # Close of has_nav_menu() ?>
	
	<div id="blog-title-wrap" class="group">
		<h1 id="blog-title"> 	
			<a href="<?php echo site_url();?>">
				<?php bloginfo( 'name' );?>	
			</a>	
		</h1>	
		<div id="blog-desc">
			<?php bloginfo( 'description' );?>
		</div>	<!-- close of id="blog-desc" -->	
	</div>	 <!-- close of id="blog-title-wrap"  -->
	
	<?php 
		if ( is_singular() && has_post_thumbnail( $post->ID )  ) {
	?>
		<a href="<?php echo esc_url( home_url( '/' ) );  ?>"><?php echo get_the_post_thumbnail( $post->ID, 'post-thumbnail' );?></a>
		<?php 
			# Assume the size of Featured Image, aka, post thumbnail is same as that of custom header size!
			# If not, overflow is hidden.
		}
		else { 
			# Display the default _custom_ header image, if no post thumbnail was chosen. 
			$header_image = get_header_image();
			if ( $header_image ) {
		?>
		
			<a href="<?php echo esc_url( home_url( '/' ) );  ?>">
				<img id="header-img" src="<?php header_image(); ?>" height="<?php echo get_custom_header()->height; ?>" width="<?php echo get_custom_header()->width; ?>" alt="" />	
			</a>		
		<?php 
			}
		} # Close of is_singular && ....		
	?>
	
	<!-- A scroll to easer -->
	<a href="#" title="Head back to top?">
		<div id="ease-scroll">
			<span id="scroll-top"></span>
		</div>
	</a>
	
</div> <!-- close of id="header" -->